.. -*- coding: utf-8 -*-

Online documentation system
===========================

.. automodule:: cubicweb.web.views.wdoc

Help views
----------
.. autoclass:: cubicweb.web.views.wdoc.InlineHelpView

Actions
-------
.. autoclass:: cubicweb.web.views.wdoc.HelpAction
.. autoclass:: cubicweb.web.views.wdoc.AboutAction
